@@ -88,12 +88,6 @@ logrxAddin <- function() {
                                            width = '100%')
             )),
          #User name check box
-         shiny::fluidRow(
-            shiny::column(
-               12,
-               shiny::checkboxInput("rmLog", "Remove the log object after axecution?", TRUE)
-            )
-         ),
          shiny::fluidRow(
             shiny::column(
                12,
@@ -167,7 +161,7 @@ logrxAddin <- function() {
             html = spin_solar() # use a spinner
          )
          axecute(file = logInfo$file, log_name = logInfo$name,
-                 log_path = logInfo$location, remove_log_object = input$rmLog,
+                 log_path = logInfo$location,
                  to_report = input$toReport)
          doneCheck$data <- "Select a new file, if you wish to run more files"
          waiter_hide() # hide the waiter
